@@ -2,7 +2,7 @@
  *
  * main server program.
  *
- * $Id: lshd.c,v 1.49 1999/05/12 21:35:21 nisse Exp $ */
+ * $Id: lshd.c,v 1.52 1999/06/11 23:46:55 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -46,6 +46,7 @@
 #include "xalloc.h"
 #include "compress.h"
 #include "server_pty.h"
+#include "tcpforward.h"
 
 #include "getopt.h"
 
@@ -65,6 +66,9 @@
 #include <unistd.h>
 #endif
 
+/* FIXME: Add configure and runtime options instead */
+#define WITH_TCPFORWARD_SUPPORT 1
+
 /* Block size for stdout and stderr buffers */
 #define BLOCK_SIZE 32768
 
@@ -177,10 +181,10 @@ static int do_read_key(struct sexp_handler *h, struct sexp *private)
 #endif
 	  
 	  verbose("lshd: Using (public) hostkey:\n"
-		  "  p=%hn\n"
-		  "  q=%hn\n"
-		  "  g=%hn\n"
-		  "  y=%hn\n",
+		  "  p=%xn\n"
+		  "  q=%xn\n"
+		  "  g=%xn\n"
+		  "  y=%xn\n",
 		  p, q, g, y);
 		  
 	  res = LSH_OK | LSH_CLOSE;
@@ -460,7 +464,14 @@ int main(int argc, char **argv)
 				   &unix_userauth.super, -1),
 			make_alist(1, ATOM_SSH_CONNECTION,
 				   make_server_connection_service
-				   (make_alist(0, -1),
+				   (make_alist
+				    (0
+#if WITH_TCPFORWARD_SUPPORT
+				     +2,
+				     ATOM_TCPIP_FORWARD, make_tcpip_forward_request(backend),
+				     ATOM_CANCEL_TCPIP_FORWARD, make_cancel_tcpip_forward_request()
+#endif /* WITH_TCPFORWARD_SUPPORT */
+				     ,-1),
 				    make_alist
 				    (1
 #if WITH_PTY_SUPPORT
